@@ -14,6 +14,7 @@ from .utils.misc import (
     log_data,
     log_file,
     log_final,
+    log_warn,
 )
 from inputimeout import inputimeout, TimeoutOccurred
 
@@ -46,7 +47,7 @@ async def process_h2r(id: str, chapter: int):
     if not os.path.exists(neat_dir):
         os.makedirs(neat_dir)
 
-    if len(img) == len(os.listdir(neat_dir)):
+    if len(img) == len(os.listdir(neat_dir)) or len(img) <= len(os.listdir(neat_dir)):
         print(
             "All images already downloaded! If you're doubt kindly remove this folder and re-download"
         )
@@ -58,7 +59,15 @@ async def process_h2r(id: str, chapter: int):
         img_url = i
         img_name = img_url.rsplit("/", 1)[-1]
 
-        r = requests.get(img_url)
+        while True:
+            try:
+                r = requests.get(img_url)
+                break
+            except Exception as e:
+                log_warn(e, f"Retrying {img_name} in 3 seconds...")
+                time.sleep(3)
+                continue
+
         with open(neat_dir + "/" + img_name, "wb") as f:
 
             f.write(r.content)
@@ -121,4 +130,6 @@ async def process_h2r(id: str, chapter: int):
                         return
 
                 except TimeoutOccurred:
-                    print(f"Timeout occurred, not rendering pdf {id}, chapter: {chapter}")
+                    print(
+                        f"Timeout occurred, not rendering pdf {id}, chapter: {chapter}"
+                    )
